@@ -53,7 +53,7 @@ class CommandCaller:
         return self.ts3audiobot.request("bot/connect/template/{template}".format(template=format_url(template)))
 
     def connect_new(self, ip):
-        return self.ts3audiobot.request("bot/connect/to/{ip}".format(ip=format_url(ip)))
+        return self.ts3audiobot.request("bot/connect/to/{ip}".format(ip=ip))
 
     def get_information(self):
         return self.ts3audiobot.request("bot/info")
